<%@ page contentType="text/html; charset=UTF-8" language="java" %>
<%@ taglib prefix="c" uri="http://java.sun.com/jsp/jstl/core" %>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>电脑产品列表</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script src="https://www.liyansheng.top/cdn/watermark.js"></script>
</head>

<body>
    <div class="container mt-5">
        <!-- 顶部导航 -->
        <div class="card shadow">
            <div class="card-header bg-primary text-white text-center">
                <h2>电脑商城</h2>
            </div>
            <div class="card-body">
                <p class="text-center">你好！<strong>${sessionScope.user.username}</strong></p>
                <c:if test="${sessionScope.user != null}">
                    <div class="d-grid gap-2 d-md-flex justify-content-md-center">
                        <a href="/computer?action=list" class="btn btn-outline-primary">电脑选购</a>
                        <c:if test="${sessionScope.user.role == 'user'}">
                            <a href="/cart?action=list" class="btn btn-outline-primary">我的购物车</a>
                            <a href="/orders?action=my" class="btn btn-outline-primary">我的订单</a>
                        </c:if>
                        <c:if test="${sessionScope.user.role == 'admin'}">
                            <a href="/user?action=list" class="btn btn-outline-primary">用户列表</a>
                            <a href="/orders?action=all" class="btn btn-outline-primary">所有订单</a>
                        </c:if>
                        <a href="/logout" class="btn btn-danger">退出</a>
                    </div>
                </c:if>
                <c:if test="${sessionScope.user == null}">
                    <p class="text-center">请登录后查看更多内容~</p>
                    <div class="d-grid gap-2 d-md-flex justify-content-md-center">
                        <a href="/register" class="btn btn-outline-primary">注册</a>
                        <a href="/login" class="btn btn-outline-primary">登录</a>
                    </div>
                </c:if>
            </div>
        </div>

        <!-- 产品列表 -->
        <div class="mt-4">
            <h1 class="text-center">电脑产品列表</h1>
            <table class="table table-bordered table-striped text-center mt-3">
                <thead class="table-primary">
                    <tr>
                        <th>ID</th>
                        <th>名称</th>
                        <th>价格</th>
                        <th>库存</th>
                        <th>操作</th>
                    </tr>
                </thead>
                <tbody>
                    <c:forEach var="computer" items="${computers}">
                        <tr>
                            <td>${computer.id}</td>
                            <td>${computer.name}</td>
                            <td>${computer.price}</td>
                            <td>${computer.stock}</td>
                            <td>
                                <c:if test="${sessionScope.user.role == 'admin'}">
                                    <a href="/computer?action=edit&id=${computer.id}" class="btn btn-sm btn-warning">编辑</a>
                                    <a href="/computer?action=delete&id=${computer.id}" class="btn btn-sm btn-danger">删除</a>
                                </c:if>
                                <c:if test="${sessionScope.user.role == 'user'}">
                                    <a href="/cart?action=add&id=${computer.id}" class="btn btn-sm btn-success">加购</a>
                                </c:if>
                            </td>
                        </tr>
                    </c:forEach>
                </tbody>
            </table>
        </div>

        <!-- 分页导航 -->
        <div class="d-flex justify-content-center mt-4">
            <nav aria-label="Page navigation">
                <ul class="pagination">
                    <li class="page-item"><a href="/computer?action=list&page=1" class="page-link">首页</a></li>
                    <c:if test="${currentPage > 1}">
                        <li class="page-item">
                            <a href="/computer?action=list&page=${currentPage - 1}" class="page-link">上一页</a>
                        </li>
                    </c:if>
                    <c:forEach var="i" begin="1" end="${totalPages}">
                        <li class="page-item ${i == currentPage ? 'active' : ''}">
                            <a href="/computer?action=list&page=${i}" class="page-link">${i}</a>
                        </li>
                    </c:forEach>
                    <c:if test="${currentPage < totalPages}">
                        <li class="page-item">
                            <a href="/computer?action=list&page=${currentPage + 1}" class="page-link">下一页</a>
                        </li>
                    </c:if>
                    <li class="page-item"><a href="/computer?action=list&page=${totalPages}" class="page-link">尾页</a></li>
                </ul>
            </nav>
        </div>

        <!-- 底部功能 -->
        <div class="text-center mt-4">
            <c:if test="${sessionScope.user.role == 'user'}">
                <a href="/cart?action=list" class="btn btn-outline-primary">我的购物车</a>
            </c:if>
            <c:if test="${sessionScope.user.role == 'admin'}">
                <a href="/computer?action=add" class="btn btn-outline-primary">发布电脑产品</a>
            </c:if>
        </div>

        <!-- 消息提示 -->
        <div class="text-center text-danger mt-3">
            <p>${requestScope.msg}</p>
        </div>
    </div>
</body>

</html>
